# Welcome to the Unofficial YC Alum Hardware Reunion!

## How to reprogram your badge

### 1. Get an NFC tools app

We recommend using **NFC Tools** ([iOS](https://apps.apple.com/us/app/nfc-tools/id1252962749) / [Android](https://play.google.com/store/apps/details?id=com.wakdev.wdnfc&hl=en_US))


### 2. Get a URL you like

If you want to use LinkedIn, it can be a good idea to [shorten your URL first](https://www.linkedin.com/help/linkedin/answer/a542685/manage-your-public-profile-url?lang=en)

![IMG_9843 3](https://github.com/user-attachments/assets/85c37249-99f7-496f-9a01-272459c025ef)

Grab the URL from the app here

### 3. Stick it on the badge

Add a URI/URL record, then write it to the badge.

![ScreenRecording_10-06-2024 11-37-28_1](https://github.com/user-attachments/assets/1ea51b39-bf97-485a-9712-45deab7cab15)
